Conversions
===========

Decibels
--------

.. python-apigen-group:: conversions-decibels

Ratios
------

.. python-apigen-group:: conversions-ratios

From $E_b/N_0$
--------------

.. python-apigen-group:: conversions-from-ebn0

From $E_s/N_0$
--------------

.. python-apigen-group:: conversions-from-esn0

From $S/N$
----------

.. python-apigen-group:: conversions-from-snr
